Detecting corners location in subpixeles {#tutorial_corner_subpixeles}
========================================

Goal
----

In this tutorial you will learn how to:

-   Use the OpenCV function @ref cv::cornerSubPix to find more exact corner positions (more exact
    than integer pixels).

Theory
------

Code
----

This tutorial code's is shown lines below. You can also download it from
[here](https://github.com/opencv/opencv/tree/master/samples/cpp/tutorial_code/TrackingMotion/cornerSubPix_Demo.cpp)
@include samples/cpp/tutorial_code/TrackingMotion/cornerSubPix_Demo.cpp

Explanation
-----------

Result
------

![](images/Corner_Subpixeles_Original_Image.jpg)

Here is the result:

![](images/Corner_Subpixeles_Result.jpg)
